==> ogre-1.9_1.9.0+dfsg1.orig.tar.xz: ogre-1.9.0/RenderSystems/GL3Plus/include/OgreGL3PlusDepthBuffer.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2013 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#ifndef __GL3PlusDepthBuffer_H__
#define __GL3PlusDepthBuffer_H__

#include "OgreGL3PlusPrerequisites.h"
#include "OgreDepthBuffer.h"


namespace Ogre 
{
    class GL3PlusContext;
    class GL3PlusRenderBuffer;
    class GL3PlusRenderSystem;
	/**
		@copydoc DepthBuffer

		OpenGL supports 3 different methods: FBO, pbuffer & Copy.
		Each one has it's own limitations. Non-FBO methods are solved using "dummy" DepthBuffers.
		That is, a DepthBuffer pointer is attached to the RenderTarget (for the sake of consistency)
		but it doesn't actually contain a Depth surface/renderbuffer (mDepthBuffer & mStencilBuffer are
		null pointers all the time) Those dummy DepthBuffers are identified thanks to their GL context.
		Note that FBOs don't allow sharing with the main window's depth buffer. Therefore even
		when FBO is enabled, a dummy DepthBuffer is still used to manage the windows.
	*/
	class _OgreGL3PlusExport GL3PlusDepthBuffer : public DepthBuffer
	{
	public:
		GL3PlusDepthBuffer( uint16 poolId, GL3PlusRenderSystem *renderSystem, GL3PlusContext *creatorContext,
						GL3PlusRenderBuffer *depth, GL3PlusRenderBuffer *stencil,
						uint32 width, uint32 height, uint32 fsaa, uint32 multiSampleQuality,
						bool manual );
		~GL3PlusDepthBuffer();

		/// @copydoc DepthBuffer::isCompatible
		virtual bool isCompatible( RenderTarget *renderTarget ) const;

		GL3PlusContext* getGLContext() const { return mCreatorContext; }
		GL3PlusRenderBuffer* getDepthBuffer() const  { return mDepthBuffer; }
		GL3PlusRenderBuffer* getStencilBuffer() const { return mStencilBuffer; }

	protected:
		uint32					mMultiSampleQuality;
		GL3PlusContext				*mCreatorContext;
		GL3PlusRenderBuffer			*mDepthBuffer;
		GL3PlusRenderBuffer			*mStencilBuffer;
		GL3PlusRenderSystem			*mRenderSystem;
	};
}
#endif

==> ogre-1.12_1.12.10+dfsg2.orig.tar.xz: ogre-1.12-1.12.10+dfsg2/RenderSystems/GL3Plus/include/OgreGL3PlusDepthBuffer.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#ifndef __GL3PlusDepthBuffer_H__
#define __GL3PlusDepthBuffer_H__

#include "OgreGL3PlusPrerequisites.h"
#include "OgreGLDepthBufferCommon.h"

namespace Ogre 
{
    class _OgreGL3PlusExport GL3PlusDepthBuffer : public GLDepthBufferCommon
    {
    public:
        GL3PlusDepthBuffer( uint16 poolId, GL3PlusRenderSystem *renderSystem, GLContext *creatorContext,
                        GL3PlusRenderBuffer *depth, GL3PlusRenderBuffer *stencil,
                        uint32 width, uint32 height, uint32 fsaa,
                        bool manual );
    };
}
#endif
